@@ -4,7 +4,7 @@ import xgboost as xgb
 import lightgbm as lgb
 import pandas as pd
 import time
-import category_encoders as ce
+#import category_encoders as ce
 from hyperopt import hp, Trials, STATUS_OK, fmin, tpe, anneal
 import matplotlib.pyplot as plt
 from statsmodels.nonparametric.smoothers_lowess import lowess
@@ -260,28 +260,26 @@ def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
     Outputs:
         dict that contains the best params and the best number of iterations
     """
-    HYPEROPT_PARAMS = {'objective': 'tweedie',
-                                'tweedie_variance_power': hp.uniform('tweedie_variance_power', 1.0, 2.0),
-                                'learning_rate': hp.loguniform('learning_rate', np.log(0.01), np.log(0.3)),
-                                'num_leaves': hp.choice('num_leaves', [2 ** i - 1 for i in range(3, 13)]),
-                                'max_depth': hp.quniform('max_depth', 2, 10, 2),  # 10,
-                                'min_data_in_leaf': hp.choice('min_data_in_leaf', [2 ** i - 1 for i in range(3, 13)]),
-                                # 'min_child_weight': hp.loguniform('min_child_weight', -16, 5)
-                                'bagging_fraction': hp.uniform('bagging_fraction', 0.2, 0.9),
-                                'bagging_freq': hp.uniform('bagging_freq', 1, 10),
-                                'feature_fraction': hp.uniform('feature_fraction', 0.2, 0.9),
-                                'lambda_l1': hp.loguniform('lambda_l1', 0, np.log(100)),
-                                'lambda_l2': hp.loguniform('lambda_l2', 0, np.log(20)),
-                                'max_bin': hp.choice('max_bin', [2 ** i - 1 for i in range(3, 11)]),
-                                'metric': 'rmse',
-                                'seed': hp.choice('seed', [0, 1, 2, 3]),
-                                'num_threads': 5,
-                                # 'gpu_id': 0,
-                                'device_type ':device.lower()
-                                }
+    HYPEROPT_PARAMS = {'learning_rate': hp.loguniform('learning_rate', np.log(0.01), np.log(0.3)),
+                        'num_leaves': hp.choice('num_leaves', [2 ** i - 1 for i in range(3, 11)]),
+                        'max_depth': hp.quniform('max_depth', 2, 10, 2),  # 10,
+                        'min_data_in_leaf': hp.choice('min_data_in_leaf', [2 ** i - 1 for i in range(3, 11)]),
+                        # 'min_child_weight': hp.loguniform('min_child_weight', -16, 5)
+                        'bagging_fraction': hp.uniform('bagging_fraction', 0.2, 0.9),
+                        'bagging_freq': hp.uniform('bagging_freq', 1, 10),
+                        'feature_fraction': hp.uniform('feature_fraction', 0.2, 0.9),
+                        'lambda_l1': hp.loguniform('lambda_l1', 0, np.log(100)),
+                        'lambda_l2': hp.loguniform('lambda_l2', 0, np.log(20)),
+                        'max_bin': hp.choice('max_bin', [2 ** i - 1 for i in range(3, 11)]),
+                        'metric': 'rmse',
+                        'seed': hp.choice('seed', [0, 1, 2, 3]),
+                        'num_threads': 5,
+                        # 'gpu_id': 0,
+                        'device_type ':device.lower()
+                        }
 
     HYPEROPT_PARAMS = _update_params(HYPEROPT_PARAMS, params)
-    INTEGER_PARAMS_LIST = ['max_depth', 'seed', 'max_bin']
+    INTEGER_PARAMS_LIST = ['max_depth', 'seed', 'max_bin', 'bagging_freq']
 
     dataset = lgb.Dataset(X_train, label=y_train, categorical_feature =cat_features)
 
@@ -296,7 +294,6 @@ def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
                     train_set=dataset,
                     nfold=cv_folds,
                     stratified=False,
-                    metrics=params['eval_metric'],
                     verbose_eval=False,
                     seed=seed,
                     num_boost_round=max_rounds,
